@@ -102,6 +102,8 @@ def admin_char_json(request):
 
     char_data = []
     for c in char_level.keys():
+        if c.eve_character is None:
+            continue
         char_data.append(
             {
                 "name": bootstrap_icon_plus_name_html(
@@ -133,6 +135,9 @@ def main_data_helper(chars):
     char2user = {}
 
     for char in chars:
+        if char.main_character is None:
+            logger.error(f"Missing main: {char}")
+            continue
         m = char.main_character
         char2user[m] = char.user.pk
         if m not in main_level:
@@ -335,17 +340,19 @@ def admin_corp_ledger(request):
         except EveCharacter.DoesNotExist:
             name = f"<a href='https://evewho.com/character/{char}'>{char}</a>"
             pass
+        except Exception as e:
+            logger.error(f"Error unknown user: {char}, error: {e}")
+            continue
         if eve_char is not None:
             try:
                 character = eve_char.miningtaxes_character
                 name = character.main_character.character_name
             except AttributeError:
-                char_name = eve_char.name
-                usermain = (
-                    eve_char.character_ownership.user.profile.main_character.character_name
-                )
-                name = f"{char_name} ({usermain})"
+                name = eve_char.character_name
                 pass
+            except Exception as e:
+                logger.error(f"Error unknown user: {eve_char}, error: {e}")
+                continue
         data.append(
             {
                 "date": o.date,
@@ -605,6 +612,13 @@ def admin_tax_revenue_json(request):
 @permission_required("miningtaxes.auditor_access")
 def admin_month_json(request):
     characters = Character.objects.all()
+    newchars = []
+    for c in characters:
+        if c.main_character is None:
+            logger.error(f"Missing main for {c}")
+            continue
+        newchars.append(c)
+    characters = newchars
     monthly = list(map(lambda x: x.get_monthly_taxes(), characters))
     users = list(map(lambda x: x.main_character.character_name, characters))
     firstmonth = None
@@ -694,6 +708,8 @@ def all_tax_credits(request, user_pk: int):
     characters = Character.objects.owned_by_user(user)
     allcredits = []
     for c in characters:
+        if c.eve_character is None:
+            continue
         allcredits += map(
             lambda x: {
                 "date": x.date,
@@ -720,6 +736,9 @@ def leaderboards(request):
     combined = {}
     for i, entries in enumerate(allentries):
         c = characters[i].main_character
+        if c is None:
+            logger.error(f"Missing main for {c}")
+            continue
         for m in entries.keys():
             if m not in combined:
                 combined[m] = {}
@@ -908,10 +927,8 @@ def character_viewer(request, character_pk: int):
     return render(request, "miningtaxes/character_viewer.html", context)
 
 
-@login_required
-@cache_page(MININGTAXES_TAX_CACHE_VIEW_TIMEOUT)
-@permission_required("memberaudit.basic_access")
-def character_mining_ledger_data(request, character_pk: int) -> JsonResponse:
+def char_mining_ledger_data(request, character_pk: int) -> JsonResponse:
+    logger.error("HERE")
     character = Character.objects.get(pk=character_pk)
     if request.user != character.user and not request.user.has_perm(
         "miningtaxes.auditor_access"
